@@ -28,30 +28,46 @@
 
 G_BEGIN_DECLS
 
+#include <libgd/gd-types-catalog.h>
+
 #ifdef LIBGD_GTK_HACKS
 # include <libgd/gd-icon-utils.h>
-# include <libgd/gd-entry-focus-hack.h>
+#endif
+
+#ifdef LIBGD__BOX_COMMON
+# include <libgd/gd-main-box-child.h>
+# include <libgd/gd-main-box-generic.h>
+# include <libgd/gd-main-box-item.h>
+#endif
+
+#ifdef LIBGD_MAIN_ICON_BOX
+# include <libgd/gd-main-icon-box.h>
+# include <libgd/gd-main-icon-box-child.h>
+#endif
+
+#ifdef LIBGD_MAIN_BOX
+# include <libgd/gd-main-box.h>
 #endif
 
 #ifdef LIBGD__VIEW_COMMON
 # include <libgd/gd-main-view-generic.h>
 # include <libgd/gd-styled-text-renderer.h>
-# include <libgd/gd-toggle-pixbuf-renderer.h>
 # include <libgd/gd-two-lines-renderer.h>
 #endif
 
 #ifdef LIBGD_MAIN_ICON_VIEW
 # include <libgd/gd-main-icon-view.h>
+# include <libgd/gd-toggle-pixbuf-renderer.h>
+#endif
+
+#ifdef LIBGD_MAIN_LIST_VIEW
+# include <libgd/gd-main-list-view.h>
 #endif
 
 #ifdef LIBGD_MAIN_VIEW
 # include <libgd/gd-main-view.h>
 #endif
 
-#ifdef LIBGD_MAIN_TOOLBAR
-# include <libgd/gd-main-toolbar.h>
-#endif
-
 #ifdef LIBGD_MARGIN_CONTAINER
 # include <libgd/gd-margin-container.h>
 #endif
